@@ -24,7 +24,7 @@ stocks_reference = {
 }
 
 
-def aggregates(stock_ticker, multiplier, timespan, from, to, external=False, **query_params):
+def aggregates(stock_ticker, multiplier, timespan, from_date, to_date, external=False, **query_params):
     """
     :return: Get aggregate bars for a stock over a given date range in custom time window sizes.
 
@@ -47,7 +47,7 @@ def aggregates(stock_ticker, multiplier, timespan, from, to, external=False, **q
     :param limit: Limits the number of base aggregates queried to create the aggregate results.
     :type limit: optional, integer, default 5000, max 50000
     """
-    URL_EXTENSION = F"/v2/aggs/ticker/{stock_ticker}/range/{multiplier}/{timespan}/{from}/{to}"
+    URL_EXTENSION = F"/v2/aggs/ticker/{stock_ticker}/range/{multiplier}/{timespan}/{from_date}/{to_date}"
     instance = polygonCommon(URL_EXTENSION, external=external)
     if query_params:
         instance.append_query_params_to_url(query_params)
